@@ -1,5 +1,5 @@
 def test_can_load():
-    from margo_loader import nbloader
+    from margo_loader import nbloader  # noqa: F401
 
 
 def test_imports_cells():
@@ -20,7 +20,8 @@ def test_imports_ipynb_docstring():
 
     assert hello_notebook.__doc__.startswith("# A regular notebook")
 
+
 def test_loads_notebook_with_spaces():
     from test_notebooks import hello_with_spaces
 
-    assert hello_with_spaces.greeting == "Hello, world!"
\ No newline at end of file
+    assert hello_with_spaces.greeting == "Hello, world!"
