@@ -11,10 +11,9 @@ def test_does_not_find_dotpy_file():
 
 
 def test_does_find_nbpy_file():
-    assert (
-        resolve_path("hello_notebook_nbpy", path=["test_notebooks"])
-        == "test_notebooks/hello_notebook_nbpy.nbpy"
-    )
+    resolved_path = resolve_path("hello_notebook_nbpy", path=["test_notebooks"])
+    expected_path = "test_notebooks/hello_notebook_nbpy.nbpy"
+    assert resolved_path == expected_path
 
 
 def test_does_not_find_ipynb_if_not_looking():
@@ -22,14 +21,17 @@ def test_does_not_find_ipynb_if_not_looking():
 
 
 def test_does_find_ipynb_file():
-    assert (
-        resolve_path("hello_notebook", path=["test_notebooks"], ext="ipynb")
-        == "test_notebooks/hello_notebook.ipynb"
+    resolved_path = resolve_path(
+        "hello_notebook", path=["test_notebooks"], ext="ipynb"
     )
+    expected_path = "test_notebooks/hello_notebook.ipynb"
+    assert resolved_path == expected_path
 
 
 def test_results_match_legacy_code():
     assert resolve_path(
         "hello_notebook_nbpy", path=["test_notebooks"]
     ) == find_notebook("hello_notebook_nbpy", ["test_notebooks"])
-    assert resolve_path("hello_notebook_nbpy") == find_notebook("hello_notebook_nbpy")
+    assert resolve_path("hello_notebook_nbpy") == find_notebook(
+        "hello_notebook_nbpy"
+    )
